==> nextcloud-app-mail-0.8.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/nb.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-post",
    "Loading accounts" : "Laster kontoer",
    "Error while loading the accounts." : "Feil ved innlasting av kontoene.",
    "Can not load this folder." : "Kan ikke laste denne mappen.",
    "Searching for {query}" : "Søker etter {query}",
    "Error while deleting message." : "Feil ved sletting av melding.",
    "Forwarded message" : "Videresendt melding",
    "Choose a folder to store the attachment in" : "Velg en mappe å lagre vedlegget i",
    "Attachments saved to Files." : "Vedleggene ble lagret i Filer.",
    "Attachment saved to Files." : "Vedlegget ble lagret i Filer.",
    "Error while saving attachments to Files." : "Feil ved lagring av vedleggene i Filer.",
    "Error while saving attachment to Files." : "Feil ved lagring av vedlegget i filer.",
    "Message flag could not be set." : "Meldingsflagget kunne ikke settes.",
    "Could not move message." : "Kunne ikke flytte melding.",
    "Invalid account" : "Ugyldig konto",
    "Invalid folder" : "Ugyldig mappe",
    "Error while creating the account: " : "Feil under opprettelse av kontoen:",
    "Unknown error" : "Ukjent feil",
    "Error while updating the account: " : "Feil under oppdatering av kontoen:",
    "All inboxes" : "Alle innbokser",
    "you" : "du",
    "Send message to {email}" : "Send melding til {email}",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det oppstod et problem under lasting av {tag}{name}{endtag}",
    "Could not load your message" : "Kunne ikke laste meldingene dine",
    "Could not load the desired message" : "Kunne ikke laste den ønskede meldingen",
    "Could not load the message" : "Kunne ikka laste meldingen",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny melding \nfra {from}","%n nye meldinger \nfra {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Save" : "Lagre",
    "Saved" : "Lagret",
    "Show all folders" : "Vis alle mapper",
    "Collapse folders" : "Skjul mapper",
    "Error while deleting account." : "Feil ved sletting av konto.",
    "Choose a file to add as attachment" : "Velg en fil å legge til som vedlegg",
    "An error occurred while uploading {fname}" : "En feil inntraff under opplasting av {fname}",
    "Reply" : "Svar",
    "Send" : "Send",
    "Sending …" : "Sender…",
    "Message sent!" : "Melding sendt!",
    "Server error" : "Tjenerfeil",
    "An unknown error occurred" : "En ukjent feil oppstod",
    "Opening HTML drafts is not supported yet." : "Åpning av HTML-kladd er ikke støttet ennå.",
    "No writable calendars found" : "Ingen skrivbare kalendere funnet",
    "Error while importing the calendar event" : "Feil ved importering av kalenderhendelse",
    "Error while downloading calendar event" : "Feil ved nedlasting av kalenderhendelse",
    "& others" : "og andre",
    "Error while loading messages." : "Feil ved innlasting av meldinger.",
    "Error while refreshing messages." : "Feil under gjenoppfrisking av meldinger.",
    "Setting up your account" : "Oppsett av kontoen din",
    "Inbox" : "Innboks",
    "Sent" : "Sendt",
    "Drafts" : "Kladd",
    "Archive" : "Arkiv",
    "Trash" : "Papirkurv",
    "Junk" : "Søppel",
    "All" : "Alle",
    "Favorites" : "Favoritter",
    "Auto detect failed. Please use manual mode." : "Automatisk påvisning mislyktes. Bruk manuelt oppsett.",
    "Updating account failed: " : "Oppdatering av konto mislyktes:",
    "Creating account failed: " : "Oppretting av konto mislyktes:",
    "Delete permanently" : "Slett for godt",
    "Error loading message" : "Feil ved innlasting av melding",
    "Settings" : "Innstillinger",
    "Forwarding to %s" : "Videresender til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikk her hvis du ikke blir videresendt automatisk innen noen få sekunder.",
    "Redirect" : "Videresend",
    "The link leads to %s" : "Denne lenken leder til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker å besøke den siden, kan du returnere til <a href=\"%s\">E-post</a>.",
    "Continue to %s" : "Fortsett til %s",
    "Delete account" : "Slett konto",
    "Try again" : "Prøv igjen",
    "New message" : "Ny melding",
    "Account Settings" : "Kontoinnstillinger",
    "Aliases" : "Aliaser",
    "Mail address" : "E-postadresse",
    "Display Name" : "Visningsnavn",
    "Account" : "Konto",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Speed up your Mail experience with these quick shortcuts." : "Arbeid raskere i Mail med disse raske snarveiene",
    "Compose new message" : "Lag ny melding",
    "Newer message" : "Nyere melding",
    "Older message" : "Eldre melding",
    "Toggle star" : "Merk med stjerne",
    "Toggle unread" : "Merk som ulest",
    "Delete" : "Slett",
    "Search" : "Søk",
    "Refresh" : "Oppdater",
    "Connect your mail account" : "Koble til din e-postkonto",
    "Name" : "Navn",
    "Mail Address" : "E-postadresse",
    "Password" : "Passord",
    "Manual configuration" : "Manuelt oppsett",
    "IMAP Host" : "IMAP vert",
    "IMAP security" : "IMAP sikkerhet",
    "None" : "Ingen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP Bruker",
    "IMAP Password" : "IMAP Passord",
    "SMTP Host" : "SMTP vert",
    "SMTP security" : "SMTP sikkerhet",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP Bruker",
    "SMTP Password" : "SMTP Passord",
    "Connect" : "Koble til",
    "from" : "fra",
    "to" : "ti",
    "cc" : "cc",
    "bcc" : "bcc",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Vær oppmerksom på at eposten kom fra en \"ikke svar\" adresse slik at ditt svar blir muligens ikke lest.",
    "Subject" : "Emne",
    "Save all to Files" : "Lagre alle i Filer",
    "Add mail account" : "Legg til e-postkonto",
    "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
    "No search results for" : "Ingen søkeresultater for",
    "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
    "Show images from this sender" : "Vis bilder fra denne avsenderen",
    "Forward" : "Videresend",
    "No messages in this folder" : "Ingen meldinger i denne mappen",
    "Upload attachment" : "Last opp vedlegg",
    "Add attachment from Files" : "Legg til vedlegg fra Filer",
    "Import into calendar" : "Importer til kalender",
    "Download attachment" : "Last ned vedlegg",
    "Save to Files" : "Lagre i Filer"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.11.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/nb.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-post",
    "Loading accounts" : "Laster kontoer",
    "Error while loading the accounts." : "Feil ved innlasting av kontoene.",
    "Can not load this folder." : "Kan ikke laste denne mappen.",
    "Searching for {query}" : "Søker etter {query}",
    "Error while deleting message." : "Feil ved sletting av melding.",
    "Forwarded message" : "Videresendt melding",
    "Choose a folder to store the attachment in" : "Velg en mappe å lagre vedlegget i",
    "Attachments saved to Files." : "Vedleggene ble lagret i Filer.",
    "Attachment saved to Files." : "Vedlegget ble lagret i Filer.",
    "Error while saving attachments to Files." : "Feil ved lagring av vedleggene i Filer.",
    "Error while saving attachment to Files." : "Feil ved lagring av vedlegget i filer.",
    "Message flag could not be set." : "Meldingsflagget kunne ikke settes.",
    "Could not move message." : "Kunne ikke flytte melding.",
    "Invalid account" : "Ugyldig konto",
    "Invalid folder" : "Ugyldig mappe",
    "Error while creating the account: " : "Feil under opprettelse av kontoen:",
    "Unknown error" : "Ukjent feil",
    "Error while updating the account: " : "Feil under oppdatering av kontoen:",
    "All inboxes" : "Alle innbokser",
    "you" : "du",
    "Send message to {email}" : "Send melding til {email}",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det oppstod et problem under lasting av {tag}{name}{endtag}",
    "Could not load your message" : "Kunne ikke laste meldingene dine",
    "Could not load the desired message" : "Kunne ikke laste den ønskede meldingen",
    "Could not load the message" : "Kunne ikka laste meldingen",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny melding \nfra {from}","%n nye meldinger \nfra {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Save" : "Lagre",
    "Saved" : "Lagret",
    "Show all folders" : "Vis alle mapper",
    "Collapse folders" : "Skjul mapper",
    "Error while deleting account." : "Feil ved sletting av konto.",
    "Choose a file to add as attachment" : "Velg en fil å legge til som vedlegg",
    "An error occurred while uploading {fname}" : "En feil inntraff under opplasting av {fname}",
    "Reply" : "Svar",
    "Send" : "Send",
    "Sending …" : "Sender…",
    "Message sent!" : "Melding sendt!",
    "Server error" : "Tjenerfeil",
    "An unknown error occurred" : "En ukjent feil oppstod",
    "Opening HTML drafts is not supported yet." : "Åpning av HTML-kladd er ikke støttet ennå.",
    "No writable calendars found" : "Ingen skrivbare kalendere funnet",
    "Error while importing the calendar event" : "Feil ved importering av kalenderhendelse",
    "Error while downloading calendar event" : "Feil ved nedlasting av kalenderhendelse",
    "& others" : "og andre",
    "Error while loading messages." : "Feil ved innlasting av meldinger.",
    "Error while refreshing messages." : "Feil under gjenoppfrisking av meldinger.",
    "Setting up your account" : "Oppsett av kontoen din",
    "Inbox" : "Innboks",
    "Sent" : "Sendt",
    "Drafts" : "Kladd",
    "Archive" : "Arkiv",
    "Trash" : "Papirkurv",
    "Junk" : "Søppel",
    "All" : "Alle",
    "Favorites" : "Favoritter",
    "Auto detect failed. Please use manual mode." : "Automatisk påvisning mislyktes. Bruk manuelt oppsett.",
    "Updating account failed: " : "Oppdatering av konto mislyktes:",
    "Creating account failed: " : "Oppretting av konto mislyktes:",
    "Delete permanently" : "Slett for godt",
    "Error loading message" : "Feil ved innlasting av melding",
    "Settings" : "Innstillinger",
    "Forwarding to %s" : "Videresender til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikk her hvis du ikke blir videresendt automatisk innen noen få sekunder.",
    "Redirect" : "Videresend",
    "The link leads to %s" : "Denne lenken leder til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker å besøke den siden, kan du returnere til <a href=\"%s\">E-post</a>.",
    "Continue to %s" : "Fortsett til %s",
    "Delete account" : "Slett konto",
    "Try again" : "Prøv igjen",
    "New message" : "Ny melding",
    "Account Settings" : "Kontoinnstillinger",
    "Aliases" : "Aliaser",
    "Mail address" : "E-postadresse",
    "Display Name" : "Visningsnavn",
    "Account" : "Konto",
    "Delete" : "Slett",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Speed up your Mail experience with these quick shortcuts." : "Arbeid raskere i Mail med disse raske snarveiene",
    "Compose new message" : "Lag ny melding",
    "Newer message" : "Nyere melding",
    "Older message" : "Eldre melding",
    "Toggle star" : "Merk med stjerne",
    "Toggle unread" : "Merk som ulest",
    "Search" : "Søk",
    "Refresh" : "Oppdater",
    "Connect your mail account" : "Koble til din e-postkonto",
    "Name" : "Navn",
    "Mail Address" : "E-postadresse",
    "Password" : "Passord",
    "Manual configuration" : "Manuelt oppsett",
    "IMAP Host" : "IMAP vert",
    "IMAP security" : "IMAP sikkerhet",
    "None" : "Ingen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP Bruker",
    "IMAP Password" : "IMAP Passord",
    "SMTP Host" : "SMTP vert",
    "SMTP security" : "SMTP sikkerhet",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP Bruker",
    "SMTP Password" : "SMTP Passord",
    "Connect" : "Koble til",
    "from" : "fra",
    "to" : "ti",
    "cc" : "cc",
    "bcc" : "bcc",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Vær oppmerksom på at e-posten kom fra en \"ikke svar\" adresse slik at ditt svar blir muligens ikke lest.",
    "Subject" : "Emne",
    "Save all to Files" : "Lagre alle i Filer",
    "Add mail account" : "Legg til e-postkonto",
    "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
    "No search results for" : "Ingen søkeresultater for",
    "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
    "Show images from this sender" : "Vis bilder fra denne avsenderen",
    "Forward" : "Videresend",
    "No messages in this folder" : "Ingen meldinger i denne mappen",
    "Upload attachment" : "Last opp vedlegg",
    "Add attachment from Files" : "Legg til vedlegg fra Filer",
    "Import into calendar" : "Importer til kalender",
    "Download attachment" : "Last ned vedlegg",
    "Save to Files" : "Lagre i Filer"
},
"nplurals=2; plural=(n != 1);");
